<?php

//==================================================

include ("conexion.php");



//===========ELIMINAR PRODUCTO DE PAQUETE=======================================

if (isset($_GET['claveBorra']) and isset($_GET['folio']))
{
		$borra=$_GET['claveBorra'];
		$folio=$_GET['folio'];
		$cons5="DELETE FROM contenido_paquete Where clave = '$borra' and idPaquete = '$folio'" ;
		$res5=mysql_query($cons5,$conex) or die ("No se elimino el producto del paquete");
		$cons001="SELECT * FROM productos WHERE clave='$borra'";
		$res001=mysql_query($cons001,$conex) or die ("No se ejecuto cons01");
		$nomproduct=mysql_result($res001,0,'nombre');

		echo "<p align='center' class='style3'>Producto ".$borra." - ".$nomproduct." cancelado.</p>";
		echo "<br>";

		$idpaquete=$folio;
		$consulta1="SELECT nompaquete,costo FROM paquetes WHERE idPaquete ='$idpaquete'";
		$resultado1=mysql_query($consulta1,$conex) or die ("No se realizo la consulta1");
		$nompaquete=mysql_result($resultado1,0,'nompaquete');
		$precio=mysql_result($resultado1,0,'costo');

		echo "<form id='form1' name='form1' method='post' action='editpaquete2.php'>";
		//TABLA DE NOMBRE, PRECIO Y COSTO

				echo "<table border='0' cellpadding='0' cellspacing='5' align='center'>";
					echo "<tr>";
					  echo "<td class='style4'>Nombre del paquete:
					  <input name='nombre' type='text' class='cuadrotexto' id='nombre' size='50' value='$nompaquete'></td>";
					  

					  //SACAR EL COSTO DE LOS PRODUCTOS DEL PAQUETE
					  $costoreal2=0;
					  $consulta01="SELECT clave,cantidad FROM contenido_paquete WHERE idPaquete='$idpaquete'";
					  $resultado01=mysql_query($consulta01,$conex) or die ("Fallo consulta de claves de paquete consulta01");

					  while ($fila01=mysql_fetch_row($resultado01))
					  {
						$consulta02="SELECT costounidad FROM productos WHERE clave='$fila01[0]'";
						$resultado02=mysql_query($consulta02,$conex) or die ("Fallo en consulta de costos de producto consulta02");
						@$costounidad=mysql_result($resultado02,0,'costounidad');
						$costoreal1=$costounidad*$fila01[1];
						$costoreal2=$costoreal2+$costoreal1;
					  }

					   echo "<td class='style5'>Costo real:$ "; printf ("%.2f", $costoreal2); echo"</span></td>";

					echo "</tr>";
				  echo "</table>";


	    echo "<p align='center' class='style7'>Contenido del Paquete ".$nompaquete."</p>";
	    echo "<p align='center'>";

            echo "<table align='center' cellpadding='2' class='tablaBordes'  width='800'>";
			echo "<tr class='tablaCabecera'>";

            echo "<td align='center'>";
            echo " ID ";
            echo "</td>";
            
            echo "<td>";
            echo "Nombre";
            echo "</td>";

	   		echo "<td>";
            echo "Clasificaci&oacute;n";
            echo "</td>";
            
			echo "<td align='center'>";
            echo "&nbsp;Costo&nbsp;";
            echo "</td>";
			
            /*
			echo "<td class='style4'>";
            echo "Precio Vta";
            echo "</td>";
			*/
            
            echo "<td>";
            echo "Presentaci&oacute;n";
            echo "</td>";
            
            echo "<td align='center'>";
            echo "Cantidad";
            echo "</td>";
            
	    	echo "<td align='center'>";
            echo "Eliminar";
            echo "</td>";
			
            echo "</tr>";

                $cons3="SELECT clave,cantidad FROM contenido_paquete WHERE idPaquete='$idpaquete'";
                $res3=mysql_query($cons3,$conex) or die ("No se realizo el barrido en la tabla contenido_paquete");
                while($fila2 = mysql_fetch_array($res3))
                {		
                        $query="SELECT clave,nombre,clasificacion,costounidad,precio FROM productos Where clave='$fila2[0]'";

                        $result=mysql_query($query,$conex) or die ("No se consultaron los productos");
                        $numero_filas=mysql_num_rows($result);
                        $numero_campos= mysql_num_fields($result);
                        while($fila = mysql_fetch_array($result))
                        {
							echo "<tr  class='tablaBordes'>";
							//CONSULTO NOMBRE DE LA PRESENTACION

							$cons1="SELECT idPresentacion FROM  productos WHERE clave='".$fila[0]."'";
							$res1=mysql_query($cons1,$conex) or die ("No consulto ID de presentacion");
							$idpresen=mysql_result($res1,0,'idPresentacion');

							$cons2="SELECT presentacion FROM presentaciones WHERE idPresentacion='$idpresen'";
							$res2=mysql_query($cons2,$conex) or die ("No consulto nombre de presentacion");
							$presen=mysql_result($res2,0,'presentacion');

							//ID
							echo "<td class='style1' align='center'>";
							echo $fila[0];
							echo "</td>";
							
							//NOMBRE
							echo "<td class='style1'>";
							echo utf8_encode($fila[1]);
							echo "</td>";
							
							//CLASIFICACION
							echo "<td class='style1'>";
							echo $fila[2];
							echo "</td>";
							
							//COSTO
							echo "<td class='style1' align='center'>";
							printf("$ %.2f", $fila[3]);
							echo "</td>";
							
							/*
							//PRECIO
							echo "<td class='style1' align='center'>";
							printf("$ %.2f", $fila[4]);
							//printf ("$ %.2f", $precio );
							echo "</td>";						
							*/
							
							//IMPRIMO PRESENTACION
							echo "<td class='style1'>";
							echo $presen;
							echo "</td>";
							
							//CANTIDAD
							echo "<td class='titulo' bgcolor='#999999' align='center'>";
							echo "<input type='text' name='cantidad[]' class='cuadrotexto' size='5' maxlength='5' value='".$fila2[1]."'>";
							echo "<input type='hidden' name='idprod[]' value='".$fila[0]."'>";
							echo "</td>";
							
							//ELIMINAR
							echo "<td class='style4'  align='center'>";
							echo "<a href='javascript:borra_producto(&quot;".$fila[0]."&quot;)'><img src='img/icon_delete.jpg' border='0' ALT='Borrar producto'> </a>";
							echo "</td>";

						}
						echo "</tr>";

					}

					echo "</table>";



                    echo "<input name='idpaquete' type='hidden' class='cuadrotexto' id='idpaquete' value='".$idpaquete."'>";

                    echo "</p>";

                    echo "<p align='center'>";

					echo "<input name='Submit' type='button' class='botonDefault' value='Cancelar' onclick='location.href=&quot;main.php?a=32&quot;'>&nbsp;&nbsp;<input name='Submit' type='submit' class='botonDefault' value='Guardar cambios'>";

                    echo "</p>";

                  	echo "</form>";

		mysql_free_result($res1);
		mysql_free_result($res2);
		mysql_free_result($res3);
		mysql_free_result($result);

}//END if





//================================= AGREGAR PRODUCTO A PAQUETE ======================================

if (isset($_GET['clave'])and ($_GET['cantidad']) )

{

		//OBTENGO LA CLAVE, CANTIDAD Y FOLIO
		$clave=$_GET['clave'];
		$cantidad=$_GET['cantidad'];
		$idpaquete=$_GET['folio'];

		//verifico si existe el producto ya en el paquete

		$cons10="SELECT * FROM contenido_paquete WHERE clave='$clave' and idPaquete='$idpaquete'";
		$res10=mysql_query($cons10,$conex) or die ("No se realizo cons10 de agrega producto");		

		$num_filas=mysql_num_rows($res10);

		//echo $num_filas;

		

		if ($num_filas == 0)

		{

			$cons30="INSERT INTO contenido_paquete (idPaquete,clave,cantidad) VALUES ('$idpaquete','$clave','$cantidad')";

			$res30=mysql_query($cons30,$conex) or die ("No se realizó la insercion en contenido_paquete");

			

			echo "<p align='center' class='style3'>Producto ".$clave." agregado al paquete!</p>";

		}

		else

		{

			echo "<center><span class='style3'>Ya existe el producto ".$clave." dentro del paquete,<br> si desea agregar cantidad, h&aacute;galo directamente!</span></center><br>";

		}


		//==============IMPRIMIR LA TABLA
		$consulta1="SELECT nompaquete,costo FROM paquetes WHERE idPaquete ='$idpaquete'";
		$resultado1=mysql_query($consulta1,$conex) or die ("No se realizo la consulta1");
		$nompaquete=mysql_result($resultado1,0,'nompaquete');
		$precio=mysql_result($resultado1,0,'costo');

		echo "<form id='form1' name='form1' method='post' action='editpaquete2.php'>";

		//TABLA DE NOMBRE, PRECIO Y COSTO
				echo "<table border='0' cellpadding='0' cellspacing='5' align='center'>";
					echo "<tr>";
					  echo "<td class='style4'>Nombre del paquete:
					  <input name='nombre' type='text' class='cuadrotexto' id='nombre' size='50' value='$nompaquete'></td>";

					  //SACAR EL COSTO DE LOS PRODUCTOS DEL PAQUETE

					  $costoreal2=0;
					  $consulta01="SELECT clave,cantidad FROM contenido_paquete WHERE idPaquete='$idpaquete'";
					  $resultado01=mysql_query($consulta01,$conex) or die ("Fallo consulta de claves de paquete consulta01");
					  while ($fila01=mysql_fetch_row($resultado01))
					  {
						$consulta02="SELECT costounidad FROM productos WHERE clave='$fila01[0]'";
						$resultado02=mysql_query($consulta02,$conex) or die ("Fallo en consulta de costos de producto consulta02");
						$costounidad=mysql_result($resultado02,0,'costounidad');
						$costoreal1=$costounidad*$fila01[1];
						$costoreal2=$costoreal2+$costoreal1;
					  }

					   echo "<td class='style5'>Costo real:$ "; printf ("%.2f", $costoreal2); echo"</span></td>";
					echo "</tr>";
				  echo "</table>";

	    echo "<p align='center' class='style7'>Contenido del Paquete ".$nompaquete;

	    echo "</p>";

           echo "<table align='center' cellpadding='2' class='tablaBordes' width='800'>";
			echo "<tr class='tablaCabecera' align='center'>";

            echo "<td align='center'>";
            echo " ID ";
            echo "</td>";
            
            echo "<td>";
            echo "Nombre";
            echo "</td>";

	   		echo "<td>";
            echo "Clasificaci&oacute;n";
            echo "</td>";
            
			echo "<td align='center'>";
            echo "&nbsp;Costo&nbsp;";
            echo "</td>";
			
            /*
			echo "<td class='style4'>";
            echo "Precio Vta";
            echo "</td>";
			*/
            
            echo "<td>";
            echo "Presentaci&oacute;n";
            echo "</td>";
            
            echo "<td align='center'>";
            echo "Cantidad";
            echo "</td>";
            
	    	echo "<td align='center'>";
            echo "Eliminar";
            echo "</td>";

            echo "</tr>";

            

                $cons3="SELECT clave,cantidad FROM contenido_paquete WHERE idPaquete='$idpaquete'";
                $res3=mysql_query($cons3,$conex) or die ("No se realizo el barrido en la tabla contenido_paquete");
                while($fila2 = mysql_fetch_array($res3))
                {		

                        $query="SELECT clave,nombre,clasificacion,costounidad,precio FROM productos Where clave='$fila2[0]'";
                        $result=mysql_query($query,$conex) or die ("No se consultaron los productos");
                        $numero_filas=mysql_num_rows($result);
                        $numero_campos= mysql_num_fields($result);

                        while($fila = mysql_fetch_array($result))
                        {
							echo "<tr  class='tablaBordes'>";

							//CONSULTO NOMBRE DE LA PRESENTACION

							$cons1="SELECT idPresentacion FROM  productos WHERE clave='".$fila[0]."'";
							$res1=mysql_query($cons1,$conex) or die ("No consulto ID de presentacion");
							$idpresen=mysql_result($res1,0,'idPresentacion');

							$cons2="SELECT presentacion FROM presentaciones WHERE idPresentacion='$idpresen'";
							$res2=mysql_query($cons2,$conex) or die ("No consulto nombre de presentacion");
							@$presen=mysql_result($res2,0,'presentacion');

							//ID
							echo "<td class='style1' align='center'>";
							echo $fila[0];
							echo "</td>";
							
							//NOMBRE
							echo "<td class='style1'>";
							echo utf8_encode($fila[1]);
							echo "</td>";
							
							//CLASIFICACION
							echo "<td class='style1'>";
							echo $fila[2];
							echo "</td>";
							
							//COSTO
							echo "<td class='style1' align='center'>";
							printf("$ %.2f", $fila[3]);
							echo "</td>";
							
							/*
							//PRECIO
							echo "<td class='style1' align='center'>";
							printf("$ %.2f", $fila[4]);
							//printf ("$ %.2f", $precio );
							echo "</td>";						
							*/
							
							//IMPRIMO PRESENTACION
							echo "<td class='style1'>";
							echo $presen;
							echo "</td>";
							
							//CANTIDAD
							echo "<td class='titulo' bgcolor='#999999' align='center'>";
							echo "<input type='text' name='cantidad[]' class='cuadrotexto' size='5' maxlength='5' value='".$fila2[1]."'>";
							echo "<input type='hidden' name='idprod[]' value='".$fila[0]."'>";
							echo "</td>";
							
							//ELIMINAR
							echo "<td class='style4'  align='center'>";
							echo "<a href='javascript:borra_producto(&quot;".$fila[0]."&quot;)'><img src='img/icon_delete.jpg' border='0' ALT='Borrar producto'> </a>";
							echo "</td>";
						}
						echo "</tr>";
					}
					echo "</table>";

                    echo "<input name='idpaquete' type='hidden' class='cuadrotexto' id='idpaquete' value='".$idpaquete."'>";
                   
                    echo "<p align='center'>";
					echo "<input name='Submit' type='button' class='botonDefault' value='Cancelar' onclick='location.href=&quot;main.php?a=32&quot;'>&nbsp;&nbsp;<input name='Submit' type='submit' class='botonDefault' value='Guardar cambios'>";
					 echo "</p>";
              echo "</form>";

		

		mysql_free_result($res1);

		mysql_free_result($res10);

		mysql_free_result($res2);

		mysql_free_result($res3);

		mysql_free_result($result);



}//END



//======================================================


//===CERRAR CONEXION
mysql_close($conex);


?>

